'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = checkDispatch;

var _farmhash = require('farmhash');

function checkDispatch() {
  var fatal = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : true;

  var lastActionHash = '';

  var getHash = function getHash() {
    var action = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

    return (0, _farmhash.fingerprint64)(JSON.stringify(action));
  };

  var checkHash = function checkHash() {
    var action = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

    return !(getHash(action) === lastActionHash);
  };

  var updateHash = function updateHash() {
    var action = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';

    lastActionHash = getHash(action);
  };

  return function (store) {
    return function (next) {
      return function (action) {
        if (checkHash(action)) {
          updateHash(action);
          return next(action);
        } else {
          var message = '[redux-duplicate-actions] A duplicate action has been detected. MORE INFO: ' + JSON.stringify(action, null, 2);
          if (fatal) {
            throw new TypeError(message);
          } else {
            console.warn(message);
            return next(action);
          }
        }
      };
    };
  };
}